@@ -34,6 +34,7 @@
 #include "allocator.h"
 #include "log.h"
 #include "vk_util.h"
+#include "vk_common.h"
 
 #define kLayerSettingsForceEnable "force_enable"
 #define kLayerSettingsCustomSTypeInfo "custom_stype_list"
@@ -47,6 +48,11 @@ static const VkLayerProperties kGlobalLayer = {
     "Default synchronization2 layer",
 };
 
+// Instance extensions that this layer provides:
+const VkExtensionProperties kInstanceExtensionProperties[] = {
+    VkExtensionProperties{VK_EXT_LAYER_SETTINGS_EXTENSION_NAME, VK_EXT_LAYER_SETTINGS_SPEC_VERSION}};
+const uint32_t kInstanceExtensionPropertiesCount = static_cast<uint32_t>(std::size(kInstanceExtensionProperties));
+
 static const VkExtensionProperties kDeviceExtension = {VK_KHR_SYNCHRONIZATION_2_EXTENSION_NAME,
                                                        VK_KHR_SYNCHRONIZATION_2_SPEC_VERSION};
 
@@ -128,6 +134,15 @@ VKAPI_ATTR VkResult VKAPI_CALL EnumerateDeviceExtensionProperties(VkPhysicalDevi
     return vk_outarray_status(&out);
 }
 
+VKAPI_ATTR VkResult VKAPI_CALL EnumerateInstanceExtensionProperties(const char* pLayerName, uint32_t* pPropertyCount,
+                                                                    VkExtensionProperties* pProperties) {
+    if (pLayerName && strncmp(pLayerName, synchronization2::kGlobalLayer.layerName, VK_MAX_EXTENSION_NAME_SIZE) == 0) {
+        return EnumerateProperties(synchronization2::kInstanceExtensionPropertiesCount,
+                                   synchronization2::kInstanceExtensionProperties, pPropertyCount, pProperties);
+    }
+    return VK_ERROR_LAYER_NOT_PRESENT;
+}
+
 static void CheckDeviceFeatures(PhysicalDeviceData &pdd, VkPhysicalDeviceFeatures2* pFeatures) {
     auto chain = reinterpret_cast<VkBaseInStructure*>(pFeatures->pNext);
     while (chain != nullptr) {
@@ -175,6 +190,7 @@ InstanceData::InstanceData(VkInstance inst, PFN_vkGetInstanceProcAddr gpa, const
     INIT_HOOK(vtable, instance, CreateDevice);
     INIT_HOOK(vtable, instance, EnumeratePhysicalDevices);
     INIT_HOOK(vtable, instance, EnumerateDeviceExtensionProperties);
+    INIT_HOOK(vtable, instance, EnumerateInstanceExtensionProperties);
     INIT_HOOK(vtable, instance, GetPhysicalDeviceFeatures2);
     INIT_HOOK(vtable, instance, GetPhysicalDeviceFeatures2KHR);
     INIT_HOOK(vtable, instance, GetPhysicalDeviceProperties);
@@ -224,7 +240,7 @@ void InitLayerSettings(const VkInstanceCreateInfo* pCreateInfo, const VkAllocati
     }
 
     if (vkuHasLayerSetting(layer_setting_set, kLayerSettingsCustomSTypeInfo)) {
-        vkuGetLayerSettingValues(layer_setting_set, kLayerSettingsCustomSTypeInfo, vku::custom_stype_info);
+        vkuGetLayerSettingValues(layer_setting_set, kLayerSettingsCustomSTypeInfo, vku::GetCustomStypeInfo());
     }
 
     vkuDestroyLayerSettingSet(layer_setting_set, pAllocator);
@@ -481,7 +497,7 @@ static VkPipelineStageFlags ConvertPipelineStageMask(VkPipelineStageFlags2KHR st
     }
 
     if (stage_mask & VK_PIPELINE_STAGE_2_PRE_RASTERIZATION_SHADERS_BIT_KHR) {
-        result_stage_mask = VK_PIPELINE_STAGE_VERTEX_SHADER_BIT;
+        result_stage_mask |= VK_PIPELINE_STAGE_VERTEX_SHADER_BIT;
         if (features.tessellation) {
             result_stage_mask |= VK_PIPELINE_STAGE_TESSELLATION_CONTROL_SHADER_BIT |
                                  VK_PIPELINE_STAGE_TESSELLATION_EVALUATION_SHADER_BIT;
@@ -1499,9 +1515,10 @@ extern "C" VEL_EXPORT VKAPI_ATTR VkResult VKAPI_CALL vkEnumerateInstanceExtensio
                                                                                             uint32_t* pPropertyCount,
                                                                                             VkExtensionProperties* pProperties) {
     if (pLayerName && strncmp(pLayerName, synchronization2::kGlobalLayer.layerName, VK_MAX_EXTENSION_NAME_SIZE) == 0) {
-        // VK_KHR_synchronization2 is a device extension and don't want to have it labeled as both instance and device extension
-        *pPropertyCount = 0;
-        return VK_SUCCESS;
+        return EnumerateProperties(synchronization2::kInstanceExtensionPropertiesCount,
+                                   synchronization2::kInstanceExtensionProperties,
+                                   pPropertyCount,
+                                   pProperties);
     }
     return VK_ERROR_LAYER_NOT_PRESENT;
 }
